Selection
=========

The Selection widget is a simple control for allowing the user to choose between a list of string options.

Usage
-----

.. code-block:: Python

    import toga
        
    container = toga.Selection(items=['bob', 'jim', 'lilly'])

Supported Platforms
-------------------

.. include:: ../supported_platforms/Selection.rst

Reference
---------

.. autoclass:: toga.interface.widgets.selection.Selection
   :members:
   :undoc-members:
   :inherited-members: